from datetime import datetime, timezone
from zoneinfo import ZoneInfo
import sys
import numpy as np
import couchdb 
import pandas as pd
import json
import csv
import re
from pprint import pprint
from matplotlib import pyplot as plt
import pathlib
import argparse
from configparser import ConfigParser

configtl = ConfigParser()
ini_values = ConfigParser()
# parse existing file
configtl.read('tl.ini')
ini_values.read('inputs.ini')

dataString = {"tl2": {"date": "Date", "time": "ClockTime"}}

server=configtl.get('couch', 'couch')
db_vl=configtl.get('couch', 'db')

couch = couchdb.Server(server)
db = couch[db_vl] # existing


## Eingabe von:
#    - Kalibrierscheinnummer
#    - Jahr der Kalibrierung 
#    - laufende Nummer der Kalibrierung

path=configtl.get('path', 'path_files')



cal_cert = ini_values.get('input_cer', 'cal_cert')
year = ini_values.get('input_gen', 'year')
no = ini_values.get('input_gen', 'no')
QMS="ja"   ######### ja beim Scan
kk_ik_pn= "kk" ######## kk,ik oder pn

cmd_parser = argparse.ArgumentParser(description= "Liest vorhandenen Messung aus der Couch und separate Druckwerte des LAO 5 und speichert sie als neues CouchDB-Dokument (mit inkrementierter Messnummer)")
cmd_parser.add_argument("leodata", type= pathlib.Path, metavar= "Datenpfad der LEO 5 Daten")
args = cmd_parser.parse_args()

json_file = "cal-" + year + "-tl2-kk-" + cal_cert + "_" + no
#new_doc_file = "cal-" + year + "-tl2-kk-" + cal_cert + "_" + str(int(no) + 1).zfill(4)
doc = db.get(json_file) 
#new_doc = doc
#print(json_file)
#pprint(new_doc)
#print(new_doc_file)
print(json_file)

pressure_data = {}

with open(args.leodata) as infile:
    pressure_file = json.load(infile)
#pprint(pressure_file)
for datapoint in range(len(pressure_file["Body"])):
    #print(datetime.fromisoformat(pressure_file["Body"][datapoint]["t"]))
    pressure_data[datetime.fromisoformat(pressure_file["Body"][datapoint]["t"])] = pressure_file["Body"][datapoint]["v"][0]
#pprint(pressure_data)
#print(list(pressure_data.keys())[0])

pressure_block = doc["Calibration"]["Measurement"]["Values"]["Pressure"]
datetime_block = doc["Calibration"]["Measurement"]["Values"]["DateTime"]
#pprint(pressure_block)
#pprint(datetime_block)
print(len(datetime_block[0]["Value"]))
for ts_line in range(len(datetime_block[0]["Value"])):
    dt_string = datetime_block[0]["Value"][ts_line] + " " + datetime_block[1]["Value"][ts_line]
#    print(dt_string)
    dt_value = datetime.strptime(dt_string, "%d-%m-%Y %H:%M")
    dt_value = dt_value.replace(tzinfo= ZoneInfo("Europe/Berlin"))
    #print(dt_value, dt_value.astimezone(timezone.utc))
    #if ts_line == 0:
        #print(dt_value, list(pressure_data.keys())[0], dt_value - list(pressure_data.keys())[0])
#    dt_utc = 
    min_above = min([i for i in list(pressure_data.keys()) if i > dt_value])
    max_below = max([i for i in list(pressure_data.keys()) if i <= dt_value])
        #print(min_above, max_below)
    p_interpol = ((dt_value - max_below)/(min_above - max_below) * pressure_data[max_below] + (min_above - dt_value)/(min_above - max_below) * pressure_data[min_above])
    #print(pressure_block[1]["Value"][ts_line], p_interpol, pressure_data[max_below], pressure_data[min_above])
    pressure_block[1]["Value"][ts_line] = p_interpol
doc["Calibration"]["Measurement"]["Values"]["Pressure"] = pressure_block
    
#pprint(doc)
db.save(doc)
