import time
import couchdb 
from datetime import date
from pathlib import Path
import argparse
import json
couch = couchdb.Server('http://a73434.berlin.ptb.de:5984')
db = couch['vl_db'] # existing

## checks if two floats have the same value, within a provided margin (to account for rounding errors, default 1e-5)
def compare(number: float, target: float, margin: float = 1e-5) -> bool:
    if abs(number - target) < margin:
        return True
    else:
        return False

## adds a newline character to a string (or other input convertable to a string)
def lf(input_str):
    return (str(input_str) + '\n')

## converts input into _inline_ math expression
def m_i(input_str):
    return ('$' + input_str + '$')

## converts input into math mode expression
def m_m(input_str):
    return ('\\[' + input_str + '\\]')

## converts input float into string with appropriate rounding, no scientific notation!
## Note: x.5 is rounded to next _even_ number
def r_simple(input_no, decimals):
    shifted = input_no * 10.0**decimals
    shifted = round(shifted)
    shifted = shifted / 10.0**decimals
    return f'{shifted:.{decimals}f}'

## converts input into scientific notation with specified decimals    
def r_sci(input_no, decimals):
    return (f'{input_no:.{decimals}e}')

config_file = "config.json"
with open(config_file) as fp:
	config = json.load(fp)

cmd_parser = argparse.ArgumentParser(description= "Erstellt TeX-Dokument als Zwischenschritt zum PDF-Kalibrierschein")
cmd_parser.add_argument("cal_no", type= int, metavar= "<Kalibrierschein-Nummer>")
cmd_parser.add_argument("-y", "--year", type= int, metavar= "<Messjahr>")
cmd_parser.add_argument("-n", "--number", type= int, metavar= "<laufende Nummer>")
args = cmd_parser.parse_args()

#cal_cert = "75559"
year = str(config["KS-Daten"]["Jahr"])
no = str(config["KS-Daten"]["lfd. Nr."]).zfill(4)
cal_cert = str(args.cal_no)
if args.year is not None:
	year = str(args.year)
if args.number is not None:
	no = str(args.number).zfill(4)
year_cer = year[2:]


# Druckanzeige pup_cus_ptb = 0 (PTB/Wika) ; pup_cus_ptb = 1 (customer)
#pup_cus_ptb = 0

# Druckanzeige durch eine Interpolation intp = 0 (PTB) ; intp = 1 (customer)
#intp = 1


#CertificateDate = str(date.today())
CertificateDate = date.today().isoformat()

json_file_cer = "cer-" + year + "-" + cal_cert 

print(json_file_cer)


### Kontrolle ob schon ein cer existiert #########

id_cer = 0   
    
mango = {'selector': {'_id':json_file_cer}}
for i in db.find(mango): 
    id_cer = 1
    
print(id_cer)


doc = {'_id': json_file_cer}


if id_cer == 0:
    db.save(doc)
    print ( "Warten! 2 Sekunden" )
    time.sleep ( 2 )
    print ( json_file_cer," ist in der Couch angelegt" )
    
else:
    print ( json_file_cer," ist bereits in der Couch angelegt" )

path = Path(config["Pfad"]["Kalibrierschein"])

id_ = "cal-" + year + "-tl2-kk-" + cal_cert + "_" + no
ks_file = "ks-" + cal_cert + "-" + year + ".tex"
ks = path.joinpath(ks_file)
cer = "cer-" + year + "-" + cal_cert

json_file_cal = id_
json_file_cer = cer
doc_cal = db.get(json_file_cal) 
doc_cer = db.get(json_file_cer) 



 ##### Daten aus dem cal Dokument werden eingelesen#######

std = doc_cal["Calibration"]["ToDo"]["Standard"]
kind = doc_cal["Calibration"]["ToDo"]["Type"]
gas = doc_cal["Calibration"]["ToDo"]["Gas"]
lang = doc_cal["Calibration"]["Customer"]["Lang"]
todo = doc_cal["Calibration"]["ToDo"]["Type"]
analy = doc_cal["Calibration"]["Result"]["Formula"]["Analyses"]



###### Überprüfung welches Todo   #########################

if "flow_std" in todo:
    res = 1  # Reservoir res = 1 (ja) ; res = 0 (nein)
    pup_cus_ptb = 1   # Druckanzeige pup_cus_ptb = 0 (PTB/Wika) ; pup_cus_ptb = 1 (customer)

else: 
    res = 0 # Reservoir res = 1 (ja) ; res = 0 (nein)
    pup_cus_ptb = 0    # Druckanzeige pup_cus_ptb = 0 (PTB/Wika) ; pup_cus_ptb = 1 (customer)
    

print(lang)
calibration_type = "KK"
last_cert_no = doc_cal["Calibration"]["Presettings"]

###### überprüfen ob eine letztes Cal-Zeichen gibt  #########################

if "LastCalibrationYear" in last_cert_no:
    print("\"last_cert_no\" ist vorhanden.")
    last_cert_no = doc_cal["Calibration"]["Presettings"]["LastCalibrationCertificate"]
    last_cert_year = doc_cal["Calibration"]["Presettings"]["LastCalibrationYear"]
    last_cert = last_cert_no + "\\,PTB\\," + last_cert_year[2:]
    sectionDiscription_noyes= "yes"
    print(last_cert)
    
else:
    print("\"last_cert_no\" ist nicht vorhanden.")
    sectionDiscription_noyes= "no"
    last_cert = ""



Standard = doc_cal["Calibration"]["ToDo"]["Standard"]
Land= doc_cal["Calibration"]["Customer"]["Address"]["Land"]

##### Titlepage #######
Certificate = str(doc_cal["Calibration"]["Certificate"])
ReferenceNo = doc_cal["Calibration"]["Presettings"]["ReferenceNo"]
Name= doc_cal["Calibration"]["Customer"]["Name"]
AddName= doc_cal["Calibration"]["Customer"]["AddName"]
Street= doc_cal["Calibration"]["Customer"]["Address"]["Street"]
Town= doc_cal["Calibration"]["Customer"]["Address"]["Town"]
Zipcode= doc_cal["Calibration"]["Customer"]["Address"]["Zipcode"]
ObjectOfCalibration= doc_cal["Calibration"]["CustomerObject"]["Type"]
Producer= doc_cal["Calibration"]["CustomerObject"]["Device"]["Producer"]
Type= doc_cal["Calibration"]["CustomerObject"]["Device"]["Type"]                ##########   Type
Object= doc_cal["Calibration"]["CustomerObject"]["Type"]                        ##########   Gegenstand/Object
Serial= doc_cal["Calibration"]["CustomerObject"]["Name"]                        ##########   Kennummer   
Examiner= doc_cal["Calibration"]["Measurement"]["Maintainer"]
ByOrder= "Dr. Matthias Bernien"
MeasurementDate= doc_cal["Calibration"]["Result"]["Formula"]["MeasurementDate"]

print(MeasurementDate)

obj ='\\object{'+ Object + '}\n'
manufacturer = '\\manufacturer{' + Producer +' }\n'
typ = '\\type{' +  Type + '}\n'
serialNo = '\\serialNo{' + Serial + '}\n'
applicant = '\\applicant{{' + Name + '}\n {' + Street + '} \n {' + Zipcode + ' ' + Town +'}\n {' + Land+'}}\n'
refNo = '\\refNo{ ' + ReferenceNo + '}\n'
calibMark = '\\calibMark{ ' +' ' + Certificate + ' PTB ' + year_cer + '}\n'
calibDate = '\\calibDate{' + MeasurementDate + '}\n'
examiner = '\\examiner{' + Examiner + '}\n'
certificateDate = '\\certificateDate{' + CertificateDate + '}\n'


##################  Ergebnisse ###################################################
NoOfMeasurements= doc_cal["Calibration"]["Result"]["Formula"]["NoOfMeasurements"]
TemperatureTL= doc_cal["Calibration"]["Result"]["Formula"]["TemperatureTL"]

PressureUpstream= doc_cal["Calibration"]["Result"]["Formula"]["PressureUpstream"]
PressureUpstreamMin= doc_cal["Calibration"]["Result"]["Formula"]["PressureUpstreamMin"]
PressureUpstreamMax= doc_cal["Calibration"]["Result"]["Formula"]["PressureUpstreamMax"]
LeakUncertainty= doc_cal["Calibration"]["Result"]["Formula"]["LeakUncertainty"]
PressureAtmosmin= doc_cal["Calibration"]["Result"]["Formula"]["PressureAtmosmin"]    #######  Pascal
#a =float(PressureUpstreamMin)
#b = f'{a:1f}'
#PressureUpstreamMin = b[:-2]
PressureAtmosmax= doc_cal["Calibration"]["Result"]["Formula"]["PressureAtmosmax"]
#a =float(PressureUpstreamMax)
#b = f'{a:1f}'
#PressureUpstreamMax = b[:-2]
FlowMol= doc_cal["Calibration"]["Result"]["Formula"]["FlowMol"]
FlowpV= doc_cal["Calibration"]["Result"]["Formula"]["FlowpV"]
LeakUncertainty= doc_cal["Calibration"]["Result"]["Formula"]["LeakUncertainty"]
TextDE= doc_cal["Calibration"]["CustomerObject"]["Text"]["description"]["de"]
TextEN= doc_cal["Calibration"]["CustomerObject"]["Text"]["description"]["en"]

###############################################################################################################################################################





#######  Überschriften ######################

########   Deutsch ##########################

sectionDescriptionTitle = 'Beschreibung zum Kalibriergegenstand'
sectionTitelProcedure = 'Kalibrierverfahren '
sectionTitelResult = 'Messergebnis '
sectionTitelUncertainty = 'Unsicherheit '




########   Englisch ##########################

sectionDescriptionTitle_en = 'Description relating to calibration device'
sectionTitelProcedure_en = 'Calibration procedure '
sectionTitelResult_en = 'Measurement results'
sectionTitelUncertainty_en = 'Uncertainty of Calibration'



#######  Überschriften         Ende   ######################


#######                 Formeln                     ####################

q_pV_allg = ' \\[ q_{pV} = p_{\\text{atm}} \\cdot \\frac{\\Delta V}{\\Delta t}\\] \n '
q_mol_allg = ' \\[ q_\\text{mol} = \\frac{q_{pV}}{RT}\\] \n '
q_mol_Val= 'q_\\text{mol}(\\vartheta_\\text{TL}) =\\SI{   ' + r_sci(FlowMol, 2) + ' }{\\mol\\per\\second}'
q_pV_Val_all = '\\[q_{pV}(\\vartheta_\\text{Ch}) = q_{\\text{mol}}(\\vartheta_\\text{TL})\\cdot R \\cdot (\\vartheta_\\text{Ch} + T_0)\\] '
q_pV_Val = 'q_{pV}(\\SI{23}{\\degreeCelsius})= \\num{' + r_sci(FlowpV, 2) + '} ~\\text{Pa}~\\text{m}^3~\\text{s}^{-1}'  ######### Wichtig beim deutsch/englisch Text , der Wert steht beim Englisch in einer Zeile

######## Tabellen um die Formeln zu zentriert. Bei den deutsch englischen Kalibrierschein stehen beide Ergebnisse direkt untereinander###########################

#tab_q_mol_Val= '\\begin{center}\\begin{tabular}[h]{c} $$$' + q_mol_Val + '$$$  \\\\ $$$\\begin{english} ' + q_mol_Val + ' \\end{english}$$$  \\end{tabular}\\end{center}'
tab_q_mol_Val= '\\begin{center}\\begin{tabular}[h]{c}' + m_i(q_mol_Val) + '\\\\ \\begin{english} ' + m_i(q_mol_Val) + ' \\end{english}  \\end{tabular}\\end{center}'
tab_q_mol_Val_en= ' \\[ ' + q_mol_Val + '\\] \n'

#tab_q_pV_Val= '\\begin{center}\\begin{tabular}[h]{c} $$$' + q_pV_Val + '$$$  \\\\ $$$\\begin{english} '+ q_pV_Val + '\\end{english}$$$  \\end{tabular}\\end{center}'
tab_q_pV_Val= '\\begin{center}\\begin{tabular}[h]{c}' + m_i(q_pV_Val) + '\\\\ \\begin{english} '+ m_i(q_pV_Val) + '\\end{english}  \\end{tabular}\\end{center}'
tab_q_pV_Val_en= ' \\[ '  + q_pV_Val + '\\] \n'


########        Formeln        Ende                 ######################








###### 1. Section: Beschreibung zum Kalibriergegenstand  ###################


sectionDiscription_1= TextDE ###### Beschreibung aus dem cal-Dokument
sectionDiscription_1_en= TextEN ###### Beschreibung aus dem cal-Dokument


if (sectionDiscription_noyes!= 'yes'):
    
    sectionDiscription_2= " Dies ist die erste von der PTB durchgeführte Kalibrierung."
    sectionDiscription_2_en= " This is the first calibration at PTB."
    print(" 1. durchgeführte Kalibrierung")

else:
   
    sectionDiscription_2= " Die von der PTB zuletzt durchgeführte Kalibrierung ist im Kalibrierschein " +  last_cert + " beschrieben."
    sectionDiscription_2_en= ""# The previous calibration at PTB had been carried out " +  last_cert_year + ' with the calibration mark ' + last_cert + " ."
    
    
    

sectionDiscription_1_en= TextEN ###### Beschreibung aus dem cal-Dokument

sectionDiscription = '\\section{' + sectionDescriptionTitle + '\\linebreak {\\small \\emph{' + sectionDescriptionTitle_en + '}}}\n' + sectionDiscription_1 + sectionDiscription_2 + '\n' + '\\begin{english}' + TextEN + sectionDiscription_2_en + '\\end{english} \n'
sectionDiscription_en = '\\section{'  + sectionDescriptionTitle_en +'}\n'  + TextEN + sectionDiscription_2_en 


print(sectionDiscription, " Discription funktioniert")


#######     2. Section: Procedure   ###################################


sectionProcedure1='''Der gemäß DIN 28400, Teil 1, definierte \\(pV\\)-Durchfluss \\(q_{pV}\\) des aus dem Testleck gegen Atmosphäre ausströmenden Gases wird mit dem Primärnormal TL2 des Labors für Vakuummetrologie der PTB bestimmt. 
Das Testleck ist dazu an einer kleinen abgeschlossenen Kammer mit veränderbarem Volumen angeflanscht. Die Kammer des Primärnormals und das Testleck sind gemeinsam thermisch von der Umgebung isoliert. 
Um den Druck \\(p_{\\text{atm}}\\) (atmosphärischer Luftdruck) in dem Behälter bei einströmendem Gas aus dem Testleck konstant zu halten, wird das Volumen vergrößert. 
Der \\(pV\\)-Durchfluss \\(q_{pV}\\) bei der Temperatur \\(T\\) (in K) und der zeitlichen Volumenänderung (\\(\\Delta V/\\Delta t\\)) im Primärnormal ist gegeben durch \n '''
sectionProcedure2=''' Der Druck \\(p_{\\text{atm}}\\) wird mit einem kalibrierten digitalen Manometer gemessen. 
Die zeitliche Volumenänderung (\\(\\Delta V/\\Delta t\\)) wird mit Hilfe einer kalibrierten Nadel und einer elektronischen Uhr bestimmt. 
Die molare Durchflussrate \\(q_{\\text{mol}}\\)  wird nach folgender Beziehung berechnet\n '''
sectionProcedure3=' Die molare Gaskonstante \\(R\\) hat den Wert 8,3145~\\(\\text{Pa}\\)~\\(\\text{m}^3\\)~\\(\\text{mol}^{-1}\\)~\\(\\text{K}^{-1}\\). '


sectionProcedure1_en ='''The gas flow \\(q_{pV}\\) of the leak defined by ISO 3529-1 flowing against atmosphere is measured in the primary test leak standard TL2 of PTB. 
The leak is connected to a small chamber of variable size. The chamber of the primary standard and the test leak are thermally isolated from the environment. 
The gas of the leak flowing into the chamber causes an increasing pressure, which is compensated by a change of the volume. 
The leak rate \\(q_{pV}\\) is calculated from the temporal volume change (\\(\\Delta V/\\Delta t\\)) and the pressure \\(p_{\\text{atm}}\\) (atmospheric pressure) inside the chamber at the temperature \\(T\\) (in K) via '''
sectionProcedure2_en=''' The pressure \\(p_{\\text{atm}}\\) is measured by means of a calibrated digital pressure gauge. 
The temporal volume change \\(\\Delta V/\\Delta t\\) is obtained of a calibrated needle and an electronic clock. The molar leak rate \\(q_{\\text{mol}}\\) of the test leak can be calculated by the following equation:'''
sectionProcedure3_en=' The molar gas constant \\(R\\) has the value 8.3145~\\(\\text{Pa}\\)~\\(\\text{m}^3\\)~\\(\\text{mol}^{-1}\\)~\\(\\text{K}^{-1}\\). '


sectionProcedure = '\\section{' + sectionTitelProcedure + '\\linebreak {\\small \\emph{' + sectionTitelProcedure_en + '}}}\n' + sectionProcedure1 + '\\begin{english}' + sectionProcedure1_en + '\\end{english} \n' + q_pV_allg + sectionProcedure2 + '\\begin{english}' + sectionProcedure2_en + '\\end{english} \n' + q_mol_allg + sectionProcedure3 + '\\begin{english}' + sectionProcedure3_en +'\\end{english} \n'
sectionProcedure_en = '\\section{' + sectionTitelProcedure_en + '}\n'  + sectionProcedure1_en  + q_pV_allg  + sectionProcedure2_en  + q_mol_allg  + sectionProcedure3_en 


#######     3. Section: Result   ###################################

sectionResult1 = 'Mit dem Testleck wurden insgesamt ' + str(NoOfMeasurements) + ' Leckratenbestimmungen an verschiedenen Tagen bei der Testlecktemperatur \\( \\vartheta_\\text{TL}= \\num{ ' + r_simple(TemperatureTL, 1) + '}\\pm \\SI{0.1}{\\degreeCelsius} \\) durchgeführt.\nDie Atmosphärendrücke lagen zwischen \\(p_{\\text{atm}_1}=(\\num{ ' + r_simple(PressureAtmosmin, 1) + '}\\pm \\SI{0.1})~ \\si{Pa} \\) und \\(p_{\\text{atm}_2}=(\\num{ ' + r_simple(PressureAtmosmax, 1) + '} \\pm \\num{0.1})~ \\si{Pa} \\).\n'
sectionResult2 = 'Daraus kann für den Ort mit einer Temperatur \\(\\vartheta_\\text{Ch}\\) in \\si{\\degreeCelsius}, an dem sich das Testleck befindet, mit \\(T_0 = \\SI{273.15}{\\kelvin}\\), der \\(pV\\)-Durchfluss nach folgender Beziehung berechnet werden.'
sectionResult3 = '\\linebreak Bei einer Temperatur \\( \\vartheta_\\text{Ch}= \\SI{ 23 }{\\degreeCelsius} \\) ergibt sich ein \\(pV\\)-Durchfluss \\(q_{pV}\\) von '
sectionResult4 = 'Die relative Unsicherheit \\(U\\) der angegebenen Leckraten beträgt  \\( \\SI{'+ str(LeakUncertainty) +'}{\\percent} \\).' 


sectionResult_std = 'Die mittlere molare Leckrate ergab einen Wert von:\n'
sectionResult_std_en = 'The mean leak rate (molar flow) was determined to:\n'

sectionResult_pup_mean = 'Die mittlere molare Leckrate, bei einem relativ zur Atmosphäre eingestellten Druck von \\( p_\\text{up}= \\SI{ ' + str(PressureUpstream) + '}{\\Pa} \\) (\\( \equiv \\SI{ ' + r_simple((PressureUpstream / 1E5), 1) + '}{\\bar} \\)) ergab einen Wert von:\n'
sectionResult_pup_mean_en = 'The mean leak rate (molar flow) for relativ pressure \\( p_\\text{up}= \\SI{ ' + str(PressureUpstream) + '}{\\Pa} \\) (\\( \equiv \\SI{ ' + r_simple((PressureUpstream / 1E5), 1) + '}{\\bar} \\)) at the upstream pressure side was determined to:\n'

sectionResult_pup_int1 = 'Die molare Leckrate, bei einem relativ zur Atmosphäre eingestellten Druck von \\( p_\\text{up}= \\SI{ ' + str(PressureUpstream) + '}{\\Pa} \\) (\\( \equiv \\SI{ ' + r_simple((PressureUpstream / 1E5), 1) + '}{\\bar} \\)) ergab einen Wert von:\n'
sectionResult_pup_int2 = 'Der Wert ergab sich aus der Inter- oder Extrapolation der gemessenen Werte in einem Bereich von \\(p_{\\text{up}_1}=(\\num{ ' + r_simple(PressureUpstreamMin, 1) + '}\\pm \\SI{0.1})~ \\si{Pa} \\) und \\(p_{\\text{up}_2}=(\\num{ ' + r_simple(PressureUpstreamMax, 1) + '}\\pm \\SI{0.1})~ \\si{Pa} \\). Die Unsicherheit des relativ eingestellten Drucks ist \\( \\SI{0.5}{\\percent} \\).'
sectionResult_pup_int1_en = 'The molar leak rate (molar flow) for a relative pressure of \\( p_\\text{up}= \\SI{ ' + str(PressureUpstream) + '}{\\Pa} \\) (\\( \equiv \\SI{ ' + r_simple((PressureUpstream / 1E5), 1) + '}{\\bar} \\)) at the upstream pressure side was determined to:\n'
sectionResult_pup_int2_en = 'This value is a result of inter- or extrapolation of measured values between \\(p_{\\text{up}_1}=(\\num{ ' + r_simple(PressureUpstreamMin, 1) + '}\\pm \\SI{0.1})~ \\si{Pa} \\) and \\(p_{\\text{up}_2}=(\\num{ ' + r_simple(PressureUpstreamMax, 1) + '}\\pm \\SI{0.1})~ \\si{Pa} \\). The pressure setting carries a relative uncertainty of \\( \\SI{0.5}{\\percent} \\).'


#print("sectionResult1:", sectionResult1)
#print("sectionResult_pup_mean:", sectionResult_pup_mean)
#print("q_mol_Val:", q_mol_Val)
sectionResult1_en = str(NoOfMeasurements)  + ' measurements were carried out on several days at a leak temperature \\( \\vartheta_\\text{TL}= \\num{ ' + r_simple(TemperatureTL, 1) + '}\\pm \\SI{0.1}{\\degreeCelsius} \\) (thermostated) and an atmospheric pressure between \\(p_{\\text{atm}_1}=(\\num{ ' + r_simple(PressureAtmosmin, 1) + ' }\\pm \\SI{0.1})~ \\si{ Pa} \\) and \\(p_{\\text{atm}_2}=(\\num{ ' + r_simple(PressureAtmosmax, 1) + ' } \\pm \\num{0.1})~ \\si{ Pa} \\).'
sectionResult2_en = 'From this the \\(pV\\)-flow  can be calculated for a place at a temperature \\(\\vartheta_\\text{Ch}\\) (in \\si{\\degreeCelsius}), where a device under test is mounted and  \\(T_0 = \\SI{273.15}{\\kelvin}\\), by the equation ' 
sectionResult3_en = 'At the temperature \\( \\vartheta_\\text{Ch}= \\SI{ 23 }{\\degreeCelsius} \\) the flow rate is'
sectionResult4_en = 'The relative uncertainty \\(U\\) of the stated leak rate are    \\( \\SI{'+ str(LeakUncertainty) +'}{\\percent} \\).'

if res == 1:
    print ( "Standardmessung - mit Reservoir" )
    sectionResult = '\\section{' + sectionTitelResult + '\\linebreak {\\small \\emph{' + sectionTitelResult_en + '}}}\n'     + sectionResult1      + sectionResult_std      + '\n\\begin{english}' + sectionResult1_en + sectionResult_std_en  + '\\end{english} ' +  tab_q_mol_Val
    sectionResult_en = '\\section{' + sectionTitelResult_en + '}\n'  + sectionResult1_en + sectionResult_std_en  +  tab_q_mol_Val_en
        

        

else:
    if(analy!='mean'):
        print ( "Standardmessung - ohne Reservoir" )
        
        sectionResult = '\\section{' + sectionTitelResult + '\\linebreak {\\small \\emph{' + sectionTitelResult_en + '}}}\n' \
        + sectionResult1      + sectionResult_pup_int1 + m_m(q_mol_Val) + sectionResult_pup_int2\
        + '\n\\begin{english}' + sectionResult1_en + sectionResult_pup_int1_en + m_m(q_mol_Val) + sectionResult_pup_int2_en + '\\end{english} \n' 
        
    
sectionResult = sectionResult + sectionResult2  + '\\begin{english}' + sectionResult2_en + '\\end{english} \n'  + q_pV_Val_all + sectionResult3 + '\\begin{english}' + sectionResult3_en  + '\\end{english} \n' + tab_q_pV_Val +  sectionResult4 + '\\begin{english}' + sectionResult4_en + '\\end{english} \n'
sectionResult_en = sectionResult1_en + sectionResult2_en  + q_pV_Val_all  + sectionResult3_en   + tab_q_pV_Val_en +  sectionResult4_en 




    
#######     4. Section: Uncertainty   ###################################

sectionU1 = 'Angegeben ist die erweiterte Messunsicherheit \\(U\\), die sich aus der Standardmessunsicherheit durch Multiplikation mit dem Erweiterungsfaktor \\(k = 2\\)  ergibt. Sie wurde gemäß dem „Guide to the Expression of Uncertainty in Measurement (GUM)“ ermittelt. Der Wert der Messgröße liegt dann im Regelfall mit einer Wahrscheinlichkeit von annähernd \\SI{95}{\\percent} im zugeordneten Überdeckungsintervall.\n '
sectionU1_en = 'The uncertainty \\(U\\) stated is the expanded measurement uncertainty obtained by multiplying the standard measurement uncertainty by the coverage factor \\(k = 2\\). It has been determined in accordance with the  “Guide to the Expression of Uncertainty in Measurement (GUM)”. The value of the measurand then normally lies, with a probability of approximately \\SI{95}{\\percent} within the attributed coverage interval.'

sectionU = '\\section{' + sectionTitelUncertainty + '\\linebreak {\\small \\emph{' + sectionTitelUncertainty_en + '}}}\n' + sectionU1 + '\\begin{english}' + sectionU1_en + '\\end{english} \n'
sectionU_en = '\\section{' + sectionTitelUncertainty_en + '}\n' + sectionU1_en 



if(lang!='en'):
    print("Kalibrierschein in deutsch",lang)
    
    with open(ks,'w', encoding='utf-8') as file:
        
        file.write('\\listfiles\n')
        file.write('\\documentclass[de,KK,noCMC]{kalibrierschein}\n ')
        file.write(obj)
        file.write(manufacturer)
        file.write(typ)
        file.write(serialNo)
        file.write(applicant)
        file.write(refNo)
        file.write(calibMark)
        file.write(calibDate)
        file.write('\\byOrder{Dr. M. Bernien}\n')
        file.write(examiner)
        file.write(certificateDate)
        
        file.write('\\begin{document}\n')
        
        file.write('\\printFirstPage\n')
        file.write(sectionDiscription)
        
        
        
        file.write(sectionProcedure)
        file.write('\\pagebreak ')
        file.write(sectionResult)
        file.write(sectionU)
        
        
        
        file.write('\\pagebreak ')
                
        file.write('\\printLastPage')
        file.write('\\end{document}\n')
        print("bis hier funktioniert")
else:
    print('"Kalibrierschein in ',lang, "en")
    

    with open(ks,'w', encoding='utf-8') as file:
        
        file.write('\\listfiles\n')
        file.write('\\documentclass[en,KK,noCMC]{kalibrierschein}\n ')
        file.write(obj)
        file.write(manufacturer)
        file.write(typ)
        file.write(serialNo)
        file.write(applicant)
        file.write(refNo)
        file.write(calibMark)
        file.write(calibDate)
        file.write('\\byOrder{Dr. M. Bernien}\n')
        file.write(examiner)
        file.write(certificateDate)
        
        file.write('\\begin{document}\n')
        
        file.write('\\printFirstPage\n')
        file.write(sectionDiscription_en)
        
        
        
        file.write(sectionProcedure_en)
        file.write(sectionResult_en)
        file.write(sectionU_en)
        
        
        
        file.write('\\pagebreak ')
                
        file.write('\\printLastPage')
        file.write('\\end{document}\n')
        print("bis hier funktioniert")


 ####################Erstellung des cer-Dokuments ##########################
 

 
 ##### Doukument "cer" wird erstellt#######
 

MeasurementDateBegin = doc_cal["Calibration"]["Measurement"]["Values"]["DateTime"][0]["Value"]
MeasurementDateBegin = MeasurementDateBegin[0]
MeasurementDateEnd = doc_cal["Calibration"]["Measurement"]["Values"]["DateTime"][0]["Value"]
MeasurementDateEnd = MeasurementDateEnd[-1]
DeviceClass= "TLA"


doc_cer["Certificate"]={"Meta":{"std": ["TL2"],
                                 "id":[id_], 
                                 "kind" :[kind], 
                                 "gas": [gas], 
                                 "lang":lang,
                                 "calibration_type":calibration_type, 
                                 "last_cert":last_cert}}
     
doc_cer["Certificate"]["Titlepage"]={"CertificateDate" :CertificateDate, 
                                     "FullYear": "2024",
                                     "ShortYear": "24",
                                  "MeasurementDate": MeasurementDate, 
                                  "MeasurementDateBegin": MeasurementDateBegin, 
                                  "MeasurementDateEnd": MeasurementDateEnd, 
                                  "Certificate": Certificate,
                                  "ReferenceNo": ReferenceNo,
                                  "Customer": {
                                      "Name": Name,
                                      "AddName": AddName,
                                      "Street": Street,
                                      "Town": Town,
                                     "Zipcode": Zipcode,
                                      "Land": Land,
                                      "CountryCode": Land },
                                "ObjectOfCalibration": ObjectOfCalibration,
                                "Producer": Producer,
                                 "Type": Type,
                                 "Object": Object,
                                  "Serial":  Serial ,
                                 "Examiner": Examiner,
                                 "DeviceClass": DeviceClass,
                                 "ByOrder": ByOrder,
                                  } 


doc_cer["Certificate"]["Section"]= [{"Heading": "Description relating to calibration device","Paragraph":sectionDiscription},
                                    {"Heading": "Calibration procedure","Paragraph":sectionProcedure},
                                    {"Heading": "Measurement results","Paragraph":sectionResult},
                                    {"Heading": "Uncertainty of Calibration","Paragraph":sectionU}],

doc_cer["Certificate"]["Formula"]={"NoOfMeasurements": NoOfMeasurements,
                                "FlowMol": FlowMol,
                                "FlowpV":FlowpV,
                                "TemperatureTL": TemperatureTL,
                                "LeakUncertainty": LeakUncertainty,
                                "MeasurementDate": MeasurementDate,
                                "PressureUpstream": PressureUpstream,
                                "PressureAtmosmin": PressureAtmosmin,
                                "PressureAtmosmax": PressureAtmosmax,
                                } 


                                  
 #                                 
 #
 #

db.save(doc_cer)






 
