import time
import couchdb 
from datetime import date
try:
    from configparser import ConfigParser
except ImportError:
    from ConfigParser import ConfigParser  # ver. < 3.0
    
## checks if two floats have the same value, within a provided margin (to account for rounding errors, default 1e-5)
def compare(number: float, target: float, margin: float = 1e-5) -> bool:
    if abs(number - target) < margin:
        return True
    else:
        return False

## adds a newline character to a string (or other input convertable to a string)
def lf(input_str):
    return (str(input_str) + '\n')

## converts input into _inline_ math expression
def m_i(input_str):
    return ('$' + input_str + '$')

## converts input into math mode expression
def m_m(input_str):
    return ('\\[' + input_str + '\\]')

## converts input float into string with appropriate rounding, no scientific notation!
## Note: x.5 is rounded to next _even_ number
def r_simple(input_no, decimals):
    shifted = input_no * 10.0**decimals
    shifted = round(shifted)
    shifted = shifted / 10.0**decimals
    return f'{shifted:.{decimals}f}'

## converts input into scientific notation with specified decimals    
def r_sci(input_no, decimals):
    return (f'{input_no:.{decimals}e}') 

configtl1 = ConfigParser()
ini_values = ConfigParser()
# parse existing file
configtl1.read('tl.ini')
ini_values.read('inputs.ini')
# read values from a section

cal_cert = ini_values.get('input_cer', 'cal_cert')
year = ini_values.get('input_gen',  'year')
year_str2=year[2:]
no = ini_values.get('input_gen', 'no')
path=configtl1.get('path', 'path')
server=configtl1.get('couch', 'couch')
db_vl=configtl1.get('couch', 'db')

couch = couchdb.Server(server)
db = couch[db_vl] # existing


CertificateDate = str(date.today())

json_file_cer = "cer-" + year + "-" + cal_cert 

print(json_file_cer)


### Kontrolle ob schon ein cer existiert #########

id_cer = 0   
    
mango = {'selector': {'_id':json_file_cer}}
for i in db.find(mango): 
    id_cer = 1
    
print(id_cer)


doc = {'_id': json_file_cer}


if id_cer == 0:
    db.save(doc)
    print ( "Warten! 5 Sekunden" )
    time.sleep ( 5 )
    print ( json_file_cer," ist in der Couch angelegt" )
    
else:
    print ( json_file_cer," ist bereits in der Couch angelegt" )


id_ = "cal-" + year + "-fm1-kk-" + cal_cert + "_" + no
ks = path + "ks-" + cal_cert + "-" + year + ".tex"
cer = "cer-" + year + "-" + cal_cert

json_file_cal = id_
json_file_cer = cer
doc_cal = db.get(json_file_cal) 
doc_cer = db.get(json_file_cer) 



 ##### Daten aus dem cal Dokument werden eingelesen#######

std = doc_cal["Calibration"]["ToDo"]["Standard"]
kind = doc_cal["Calibration"]["ToDo"]["Type"]
gas = doc_cal["Calibration"]["ToDo"]["Gas"]
lang = doc_cal["Calibration"]["Customer"]["Lang"]
todo = doc_cal["Calibration"]["ToDo"]["Type"]




 

print(lang)
calibration_type = "KK"
last_cert_no = doc_cal["Calibration"]["Presettings"]

###### überprüfen ob eine letztes Cal-Zeichen gibt  #########################

if "LastCalibrationYear" in last_cert_no:
    print("\"last_cert_no\" ist vorhanden.")
    last_cert_no = doc_cal["Calibration"]["Presettings"]["LastCalibrationCertificate"]
    last_cert_year = doc_cal["Calibration"]["Presettings"]["LastCalibrationYear"]
    last_cert = last_cert_no + "\\,PTB\\," + last_cert_year[2:]
    sectionDiscription_noyes= "yes"
    print(last_cert)
    
else:
    print("\"last_cert_no\" ist nicht vorhanden.")
    sectionDiscription_noyes= "no"
    last_cert = ""



Standard = doc_cal["Calibration"]["ToDo"]["Standard"]
Land= doc_cal["Calibration"]["Customer"]["Address"]["Land"]

##### Titlepage #######
Certificate = str(doc_cal["Calibration"]["Certificate"])
ReferenceNo = doc_cal["Calibration"]["Presettings"]["ReferenceNo"]
Name= doc_cal["Calibration"]["Customer"]["Name"]
AddName= doc_cal["Calibration"]["Customer"]["AddName"]
Street= doc_cal["Calibration"]["Customer"]["Address"]["Street"]
Town= doc_cal["Calibration"]["Customer"]["Address"]["Town"]
Zipcode= doc_cal["Calibration"]["Customer"]["Address"]["Zipcode"]
ObjectOfCalibration= doc_cal["Calibration"]["CustomerObject"]["Type"]
Producer= doc_cal["Calibration"]["CustomerObject"]["Device"]["Producer"]
Type= doc_cal["Calibration"]["CustomerObject"]["Device"]["Type"]                ##########   Type
Object= doc_cal["Calibration"]["CustomerObject"]["Type"]                        ##########   Gegenstand/Object
Serial= doc_cal["Calibration"]["CustomerObject"]["Name"]                        ##########   Kennummer   
Examiner= doc_cal["Calibration"]["Measurement"]["Maintainer"]
ByOrder= "Dr. Matthias Bernien"
MeasurementDate= doc_cal["Calibration"]["Result"]["Formula"]["MeasurementDate"]
QMS= doc_cal["Calibration"]["Result"]["Formula"]["QMS"]



obj ='\\object{'+ Object + '}\n'
manufacturer = '\\manufacturer{' + Producer +' }\n'
typ = '\\type{' +  Type + '}\n'
serialNo = '\\serialNo{' + Serial + '}\n'
applicant = '\\applicant{{' + Name + '}\n {' + Street + '} \n {' + Zipcode + ' ' + Town +'}\n {' + Land +'}}\n'
refNo = '\\refNo{ ' + ReferenceNo + '}\n'
calibMark = '\\calibMark{ ' +' ' + Certificate + ' PTB ' + year_str2 + '}\n'
calibDate = '\\calibDate{' + MeasurementDate + '}\n'
examiner = '\\examiner{' + Examiner + '}\n'
certificateDate = '\\certificateDate{' + CertificateDate + '}\n'




##################  Ergebnisse ###################################################
NoOfMeasurements= doc_cal["Calibration"]["Result"]["Formula"]["NoOfMeasurements"]
FlowMol= doc_cal["Calibration"]["Result"]["Formula"]["FlowMol"]
FlowpV23= doc_cal["Calibration"]["Result"]["Formula"]["FlowpV23"]
FlowpV2X= doc_cal["Calibration"]["Result"]["Formula"]["FlowpV2X"]
TemperatureTL= doc_cal["Calibration"]["Result"]["Formula"]["TemperatureTL"]
TemperatureTLx= doc_cal["Calibration"]["Result"]["Formula"]["TemperatureTLx"]

Gauge= doc_cal["Calibration"]["Result"]["Formula"]["Gauge"]
LeakUncertainty= str(doc_cal["Calibration"]["Result"]["Formula"]["LeakUncertainty"])
print("TLX= ",TemperatureTLx)
TextDE= doc_cal["Calibration"]["CustomerObject"]["Text"]["description"]["de"]
TextEN= doc_cal["Calibration"]["CustomerObject"]["Text"]["description"]["en"]

FlowpVTarget = ""
TemperatureTarget = ""

if compare(float(doc_cal["Calibration"]["ToDo"]["Values"]["Temperature"]["Value"][0]), 23.0):
    TemperatureTarget = TemperatureTL
    FlowpVTarget = FlowpV23
else:
    TemperatureTarget = r_simple(float(TemperatureTLx), 1)
    FlowpVTarget = FlowpV2X

###############################################################################################################################################################





#######  Überschriften ######################

########   Deutsch ##########################

sectionDescriptionTitle = 'Beschreibung zum Kalibriergerät'
sectionTitelProcedure = 'Kalibrierverfahren '
sectionTitelResult = 'Messergebnis '
sectionTitelUncertainty = 'Unsicherheit '




########   Englisch ##########################

sectionDescriptionTitle_en = 'Description relating to calibration device'
sectionTitelProcedure_en = 'Calibration procedure '
sectionTitelResult_en = 'Measurement results'
sectionTitelUncertainty_en = 'Uncertainty of Calibration'



#######  Überschriften         Ende   ######################


#######                 Formeln                     ####################
q_mol_FM_allg = ' \\[ q_\\text{mol, FM} = p_{\\text{FM}} ~ C ~  \\frac{1}{RT_{\\text{FM}}}\\]  '
q_mol_TL_allg = ' \\[ q_\\text{mol, TL} = q_\\text{mol, FM} ~ \\frac{S_\\text{TL}}{S_\\text{FM}}\\] \n '
q_mol_Val= 'q_\\text{mol}(\\vartheta_\\text{TL}) =\\SI{   ' + FlowMol + ' }{\\mol\\per\\second}'
q_pV_allg = ' \\[ q_{pV}(\\vartheta_\\text{Ch}) = q_{\\text{mol}} ~ R ~ (\\vartheta_\\text{Ch} + T_0) \\]  '    
#q_pV_23C = 'q_{pV}(\\SI{23}{\\degreeCelsius})= \\num{' + FlowpV23 + '} ~\\text{Pa}~\\text{m}^3~\\text{s}^{-1}'
#q_pV_2X = 'q_{pV}(\\SI{23}{\\degreeCelsius})= \\num{' + FlowpV2X + '} ~\\text{Pa}~\\text{m}^3~\\text{s}^{-1}'  
q_pV_Target = 'q_{pV}(\\SI{' + TemperatureTarget + '}{\\degreeCelsius})= \\num{' + FlowpVTarget + '} ~\\text{Pa}~\\text{m}^3~\\text{s}^{-1}'

######## Tabellen um die Formeln zu zentriert. Bei den deutsch englischen Kalibrierschein stehen beide Ergebnisse direkt untereinander###########################

tab_q_mol_Val= '\\begin{center}\\begin{tabular}[h]{c} $$$' + q_mol_Val + '$$$  \\\\ $$$\\begin{english} ' + q_mol_Val + ' \\end{english}$$$  \\end{tabular}\\end{center} '
tab_q_mol_Val_en= ' \\[ ' + q_mol_Val + '\\] \n'

tab_q_pV_Val= '\\begin{center}\\begin{tabular}[h]{c} $$$' + q_pV_Target + '$$$  \\\\ $$$\\begin{english} '+ q_pV_Target + '\\end{english}$$$  \\end{tabular}\\end{center}'
tab_q_pV_Val_en= ' \\[ '  + q_pV_Target + '\\] \n'


########        Formeln        Ende                 ######################



###### 1. Section: Beschreibung zum Kalibriergerät  ###################


sectionDiscription_1= TextDE ###### Beschreibung aus dem cal-Dokument
sectionDiscription_1_en= TextEN ###### Beschreibung aus dem cal-Dokument


if (sectionDiscription_noyes!= 'yes'):
    
    sectionDiscription_2= " Dies ist die erste von der PTB durchgeführte Kalibrierung."
    sectionDiscription_2_en= " This is the first calibration at PTB."
    print(" 1. durchgeführte Kalibrierung")

else:
   
    sectionDiscription_2= " Die von der PTB zuletzt durchgeführte Kalibrierung ist im Kalibrierschein " +  last_cert + " beschrieben."
    sectionDiscription_2_en= " The previous calibration at PTB has been carried out " +  last_cert_year + ' with the calibration mark ' + last_cert + "."
    
    
    

sectionDiscription_1_en= TextEN ###### Beschreibung aus dem cal-Dokument

sectionDiscription = '\\section{' + sectionDescriptionTitle + '\\linebreak {\\small \\emph{' + sectionDescriptionTitle_en + '}}}\n' + sectionDiscription_1 + sectionDiscription_2 + '\n' + '\\begin{english}' + TextEN + sectionDiscription_2_en + '\\end{english} \n'
sectionDiscription_en = '\\section{'  + sectionDescriptionTitle_en +'}\n'  + TextEN + sectionDiscription_2_en


print(sectionDiscription, " Description funktioniert")


#######     2. Section: Procedure   ###################################


sectionProcedure1='''Der aus dem thermostatisierten Testleck TL austretende Gasfluss \\(q_{\\text{mol, TL}}\\) wird mit Hilfe eines Massenspektrometers mit einem annähernd gleich groß eingestellten Gasfluss \\(q_{\\text{mol, FM}}\\) 
verglichen, dessen Größe mit einem Durchflussmesser (Flowmeter, FM) bestimmt wird. Die Durchflussmessung erfolgt bei konstantem Druck \\(p_{\\text{FM}}\\) und konstanter Temperatur \\(T_{\\text{FM}}\\). Der Druck \\(p_{\\text{FM}}\\) wird
 mit einem kapazitiven Membranvakuummeter gemessen. Dieses Gerät ist durch einen Vergleich mit einem Primärnormal der PTB kalibriert worden. Der Leitwert \\(C\\) wird aus der zeitlichen Volumenänderung (\\(\\Delta V/\\Delta t\\))
 eines zusammendrückbaren, kalibrierten Federbalgs (\\(\\Delta V\\)) und einer elektronischen Uhr (\\(\\Delta t\\)) ermittelt. Die molare Gaskonstante \\(R\\) hat den Wert 8,3145~\\(\\text{Pa}\\)~\\(\\text{m}^3\\)~\\(\\text{mol}^{-1}\\)~\\(\\text{K}^{-1}\\).'''

sectionProcedure2=' Die Leckrate \\(q_{\\text{mol, TL}}\\) des Testlecks wird nach folgender Beziehung berechnet:\n '
sectionProcedure3=' mit \\(S_{\\text{TL}}\\) dem Signal am Massenspektrometer für den Gasfluss des Testlecks und \\(S_{\\text{FM}}\\) dem Signal am Massenspektrometer für den eingestellten Vergleichsgasfluss.'


sectionProcedure1_en ='''The gas flow from the leak TL \\(q_{\\text{mol, TL}}\\) is compared with a gas flow \\(q_{\\text{mol, FM}}\\) of about the same flow rate from a flow meter (FM) by means of a
mass spectrometer. The flow measurement is operated at constant pressure \\(p_{\\text{FM}}\\) and constant (absolute) temperature \\(T_{\\text{FM}}\\).
The pressure \\(p_{\\text{FM}}\\) is measured with a capacitance diaphragm gauge. This gauge is calibrated by comparison with a primary
standard of PTB. The conductance \\(C\\) of the capillary integrated in the flow meter is obtained from the temporal volume change
(\\(\\Delta V/\\Delta t\\)) that is needed to keep \\(p_{\\text{FM}}\\) constant. It is measured by means of a calibrated bellow (\\(\\Delta V\\)) and an electronic clock (\\(\\Delta t\\)). The
molar gas constant \\(R\\) has the value 8.3145~\\(\\text{Pa}\\)~\\(\\text{m}^3\\)~\\(\\text{mol}^{-1}\\)~\\(\\text{K}^{-1}\\). '''
sectionProcedure2_en='The molar leak rate \\(q_{\\text{mol, TL}}\\) of the test leak can be calculated by the following equation:'
sectionProcedure3_en=' whereby \\(S_{\\text{TL}}\\) is the signal at the mass spectrometer for the gas flow from the test leak and \\(S_{\\text{FM}}\\) the signal at the mass spectrometer for the gas flow from the flow meter.'


sectionProcedure = '\\section{' + sectionTitelProcedure + '\\linebreak {\\small \\emph{' + sectionTitelProcedure_en + '}}}\n' + sectionProcedure1 + '\\begin{english}' + sectionProcedure1_en + '\\end{english} \n' + q_mol_FM_allg + sectionProcedure2 + '\\begin{english}' + sectionProcedure2_en + '\\end{english} \n' + q_mol_TL_allg + sectionProcedure3 + '\\begin{english}' + sectionProcedure3_en +'\\end{english} \n'
sectionProcedure_en = '\\section{' + sectionTitelProcedure_en + '}\n'  + sectionProcedure1_en  + q_mol_FM_allg + sectionProcedure2_en  + q_mol_TL_allg  + sectionProcedure3_en 


#######     3. Section: Result   ###################################

sectionResult1 = 'Mit dem thermostatisierten Testleck wurden insgesamt ' + NoOfMeasurements + ' Leckratenbestimmungen bei einer Testlecktemperatur von \\( \\vartheta_\\text{TL}= \\num{ ' + TemperatureTL + '}\\pm \\SI{0.1}{\\degreeCelsius} \\) durchgeführt.\n Der Mittelwert ergab die (molare) Leckrate:'
sectionResult2 = 'Daraus kann für den Ort mit einer Temperatur \\(\\vartheta_\\text{Ch}\\) in \\si{\\degreeCelsius}, an dem sich das Testleck befindet, mit \\(T_0 = \\SI{273.15}{\\kelvin}\\), der \\(pV\\)-Durchfluss nach folgender Beziehung berechnet werden.'
sectionResult3 = 'Bei einer Kammertemperatur von \\( \\vartheta_\\text{Ch}= \\SI{ ' + TemperatureTarget + ' }{\\degreeCelsius} \\) ergibt sich ein \\(pV\\)-Durchfluss \\(q_{pV}\\) '
sectionResult3_TX = 'Bei Kammertemperaturen von \\( \\vartheta_\\text{Ch}= \\SI{ ' + TemperatureTarget + ' }{\\degreeCelsius} \\) und \\( \\vartheta_\\text{Ch}= \\SI{' + TemperatureTLx + ' }{\\degreeCelsius} \\) ergeben sich \\(pV\\)-Durchflüsse \\(q_{pV}\\) von' 
sectionResult4 = 'Die relative Unsicherheit \\(U\\) der angegebenen Leckraten beträgt  \\( \\SI{'+ LeakUncertainty +'}{\\percent} \\).' 


sectionResult1_en = NoOfMeasurements  + ' measurements were carried out at a leak temperature \\( \\vartheta_\\text{TL}= \\num{ ' + TemperatureTL + '}\\pm \\SI{0.1}{\\degreeCelsius} \\) (thermostated). The mean leak rate (molar flow) was determined to:'
sectionResult2_en = ' From this the \\(pV\\)-flow  can be calculated for a place at a temperature \\(\\vartheta_\\text{Ch}\\) (in \\si{\\degreeCelsius}), where a device under test is mounted and  \\(T_0 = \\SI{273.15}{\\kelvin}\\), by the equation ' 
sectionResult3_en = 'At the temperature \\( \\vartheta_\\text{Ch}= \\SI{ ' + TemperatureTarget + ' }{\\degreeCelsius} \\) the flow rate is'
sectionResult3_TX_en = 'At the temperatures \\( \\vartheta_\\text{Ch}= \\SI{ ' + TemperatureTarget + ' }{\\degreeCelsius} \\) and \\( \\vartheta_\\text{Ch}= \\SI{ ' + TemperatureTarget + ' }{\\degreeCelsius} \\) the flow rates are'
sectionResult4_en = 'The relative uncertainty \\(U\\) of the stated leak rate is \\( \\SI{'+ LeakUncertainty +'}{\\percent} \\).'

sectionResult_en = '\\section{' + sectionTitelResult_en + '}\n'  + sectionResult1_en 
        

        

    
sectionResult = '\\section{' + sectionTitelResult + '\\linebreak {\\small \\emph{' + sectionTitelResult_en + '}}}\n'    + sectionResult1         + '\\begin{english}' + sectionResult1_en   + '\\end{english} ' + tab_q_mol_Val + sectionResult2  + '\\begin{english}' + sectionResult2_en + '\\end{english} ' + q_pV_allg  + sectionResult3 + '\\begin{english}' + sectionResult3_en  + '\\end{english} ' +  tab_q_pV_Val + sectionResult4 + '\\begin{english}' + sectionResult4_en + '\\end{english} \n'
sectionResult_en = sectionResult_en +  tab_q_mol_Val_en + sectionResult2_en  + q_pV_allg + sectionResult3_en +  tab_q_pV_Val_en + sectionResult4_en 




    
#######     4. Section: Uncertainty   ###################################

sectionU1 = 'Angegeben ist die erweiterte Messunsicherheit \\(U\\), die sich aus der Standardmessunsicherheit durch Multiplikation mit dem Erweiterungsfaktor \\(k = 2\\)  ergibt. Sie wurde gemäß dem „Guide to the Expression of Uncertainty in Measurement (GUM)“ ermittelt. Der Wert der Messgröße liegt dann im Regelfall mit einer Wahrscheinlichkeit von annähernd \\SI{95}{\\percent} im zugeordneten Überdeckungsintervall.\n '
sectionU1_en = 'The uncertainty \\(U\\) stated is the expanded measurement uncertainty obtained by multiplying the standard measurement uncertainty by the coverage factor \\(k = 2\\). It has been determined in accordance with the  “Guide to the Expression of Uncertainty in Measurement (GUM)”. The value of the measurand then normally lies, with a probability of approximately \\SI{95}{\\percent} within the attributed coverage interval.'

sectionU = '\\section{' + sectionTitelUncertainty + '\\linebreak {\\small \\emph{' + sectionTitelUncertainty_en + '}}}\n' + sectionU1 + '\\begin{english}' + sectionU1_en + '\\end{english} \n'
sectionU_en = '\\section{' + sectionTitelUncertainty_en + '}\n' + sectionU1_en 



if(lang!='en'):
    print("Kalibrierschein in deutsch",lang)
    
    with open(ks,'w', encoding='utf-8') as file:
        
        file.write('\\listfiles\n')
        file.write('\\documentclass[de,KK,CMC]{kalibrierschein}\n ')
        file.write(obj)
        file.write(manufacturer)
        file.write(typ)
        file.write(serialNo)
        file.write(applicant)
        file.write(refNo)
        file.write(calibMark)
        file.write(calibDate)
        file.write('\\byOrder{Dr. M. Bernien}\n')
        file.write(examiner)
        file.write(certificateDate)
        
        file.write('\\begin{document}\n')
        
        file.write('\\printFirstPage\n')
        file.write(sectionDiscription)
        
        
        
        file.write(sectionProcedure)
        file.write('\\pagebreak ')
        file.write(sectionResult)
        file.write(sectionU)
        
        
        
        file.write('\\pagebreak ')
                
        file.write('\\printLastPage')
        file.write('\\end{document}\n')
        print("bis hier funktioniert")
else:
    print('"Kalibrierschein in ',lang, "en")
    

    with open(ks,'w', encoding='utf-8') as file:
        
        file.write('\\listfiles\n')
        file.write('\\documentclass[en,KK,CMC]{kalibrierschein}\n ')
        file.write(obj)
        file.write(manufacturer)
        file.write(typ)
        file.write(serialNo)
        file.write(applicant)
        file.write(refNo)
        file.write(calibMark)
        file.write(calibDate)
        file.write('\\byOrder{Dr. M. Bernien}\n')
        file.write(examiner)
        file.write(certificateDate)
        
        file.write('\\begin{document}\n')
        
        file.write('\\printFirstPage\n')
        file.write(sectionDiscription_en)
        
        
        
        file.write(sectionProcedure_en)
        file.write(sectionResult_en)
        file.write(sectionU_en)
        
        
        
        file.write('\\pagebreak ')
                
        file.write('\\printLastPage')
        file.write('\\end{document}\n')
        print("bis hier funktioniert")


 ####################Erstellung des cer-Dokuments ##########################
 

 
 ##### Doukument "cer" wird erstellt#######
 

MeasurementDateBegin = doc_cal["Calibration"]["Measurement"]["Date"][0]["Value"]
MeasurementDateBegin = MeasurementDateBegin[0]
MeasurementDateEnd = doc_cal["Calibration"]["Measurement"]["Date"][0]["Value"]
MeasurementDateEnd = MeasurementDateEnd[0]
DeviceClass= "TLA"


doc_cer["Certificate"]={"Meta":{"std": ["FM1"],
                                 "id":[id_], 
                                 "kind" :[kind], 
                                 "gas": [gas], 
                                 "lang":lang,
                                 "calibration_type":calibration_type, 
                                 "last_cert":last_cert}}
     
doc_cer["Certificate"]["Titlepage"]={"CertificateDate" :CertificateDate, 
                                     "FullYear": "2024",
                                     "ShortYear": "24",
                                  "MeasurementDate": MeasurementDate, 
                                  "MeasurementDateBegin": MeasurementDateBegin, 
                                  "MeasurementDateEnd": MeasurementDateEnd, 
                                  "Certificate": Certificate,
                                  "ReferenceNo": ReferenceNo,
                                  "Customer": {
                                      "Name": Name,
                                      "AddName": AddName,
                                      "Street": Street,
                                      "Town": Town,
                                     "Zipcode": Zipcode,
                                      "Land": Land,
                                      "CountryCode": Land },
                                "ObjectOfCalibration": ObjectOfCalibration,
                                "Producer": Producer,
                                 "Type": Type,
                                 "Object": Object,
                                  "Serial":  Serial ,
                                 "Examiner": Examiner,
                                 "DeviceClass": DeviceClass,
                                 "ByOrder": ByOrder,
                                  } 

if(lang!='en'):
    doc_cer["Certificate"]["Section"]= [{"Heading": "Description relating to calibration device","Paragraph":sectionDiscription},
                                    {"Heading": "Calibration procedure","Paragraph":sectionProcedure},
                                    {"Heading": "Measurement results","Paragraph":sectionResult},
                                    {"Heading": "Uncertainty of Calibration","Paragraph":sectionU}],

else:
      doc_cer["Certificate"]["Section"]= [{"Heading": "Description relating to calibration device","Paragraph":sectionDiscription_en},
                                      {"Heading": "Calibration procedure","Paragraph":sectionProcedure_en},
                                      {"Heading": "Measurement results","Paragraph":sectionResult_en},
                                      {"Heading": "Uncertainty of Calibration","Paragraph":sectionU_en}],  

doc_cer["Certificate"]["Formula"]={"NoOfMeasurements": NoOfMeasurements,
                                "FlowMol": FlowMol,
                                "FlowpV23":FlowpV23,
                                "FlowpV2X":FlowpV2X,
                                "TemperatureTL": TemperatureTL,
                                "TemperatureTLx": TemperatureTLx,
                                "LeakUncertainty": LeakUncertainty
                                } 


                                  
                           
 #
 #

db.save(doc_cer)






 
